@@ -9,7 +9,7 @@ import threading
 logging.basicConfig(stream=sys.stdout,
                     level=os.environ.get('LOGLEVEL', logging.INFO))
 
-__version__ = '1.2.12'
+__version__ = '1.2.15'
 
 logger = logging.getLogger(__name__)
 
@@ -104,8 +104,6 @@ class RepeatedJob(object):
         if self.use_timer:
             self._timer.cancel()
         else:
-            # Stop listening
-            self.client.stop()
             # exit event message loop
             self.msgevent.set()
         self.is_running = False
